import { INotebookTracker, } from '@jupyterlab/notebook';
import { ICodeMirror } from '@jupyterlab/codemirror';
import { CodeCell } from '@jupyterlab/cells';
import { setupKatScriptCodeMirror } from './codemirror-katscript-python';
const plugin = {
    id: 'katscript-jupyter',
    autoStart: true,
    requires: [INotebookTracker, ICodeMirror],
    activate,
};
function activate(app, tracker, codemirror) {
    setupKatScriptCodeMirror(codemirror);
    const style = document.createElement('style');
    style.type = 'text/css';
    style.innerHTML = '.katscript { background-color: rgba(0, 0, 0, 0.04); }';
    document.getElementsByTagName('head')[0].appendChild(style);
    tracker.widgetAdded.connect(activate_katscript);
}
function check_all(sender) {
    sender.content.widgets.forEach(cell => {
        if (cell instanceof CodeCell &&
            cell.model.mimeType !== 'text/x-katscript-python') {
            cell.model.mimeType = 'text/x-katscript-python';
        }
    });
}
function set_mime(model) {
    // Jupyter seems to have some weirdness related to setup of the
    // mime type of each cell. To avoid having timeouts everywhere,
    // everytime we select a new cell, we attach a function that checks the
    // mime type on each content change and sets it if required, otherwise
    // disconnects itself.
    if (model.mimeType === 'text/x-katscript-python') {
        model.contentChanged.disconnect(set_mime);
    }
    else {
        model.mimeType = 'text/x-katscript-python';
    }
}
function check_cell(sender, cell) {
    if (cell instanceof CodeCell) {
        cell.model.contentChanged.connect(set_mime);
    }
}
function activate_katscript(sender, panel) {
    panel.content.activeCellChanged.connect(check_cell);
    // I ain't proud of this, but it's the sanest way I could find to get
    // the syntax highlighting to change on startup without selecting a
    // different cell
    setTimeout(() => {
        check_all(panel);
    }, 500);
    setTimeout(() => {
        check_all(panel);
    }, 2000);
    setTimeout(() => {
        check_all(panel);
    }, 5000);
}
export default plugin;
